/*
 * Copyright (c) 1998 The Santa Cruz Operation, Inc.. All Rights Reserved. 
 *                                                                         
 *        THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF THE               
 *                   SANTA CRUZ OPERATION INC.                             
 *                                                                         
 *   The copyright notice above does not evidence any actual or intended   
 *   publication of such source code.                                      
 */

#ident	"@(#)nb_ioctl.h	1.10"

/*
 * Copyrighted as an unpublished work.
 * (c) Copyright 1987-1993 Lachman Technology, Inc.
 * All rights reserved.
 *
 * RESTRICTED RIGHTS
 *
 * These programs are supplied under a license.  They may be used,
 * disclosed, and/or copied only as permitted under such license
 * agreement.  Any copy must contain the above copyright notice and
 * this restricted rights notice.  Use, copying, and/or disclosure
 * of the programs is strictly prohibited unless otherwise provided
 * in the license agreement.
 *
 */
/*      SCCS IDENTIFICATION        */
/*
 *
 * MODIFICATION HISTORY
 * WHEN		WHO	ID	WHAT
 * 23 Dec 97	stuarth	S001	Added ioctl for NBIOCTL_ASTAT_IP
 *
 */
#ifndef __nb_ioctl_h
#define __nb_ioctl_h
/*
 * NB_IOC_INIT initializes various NetBIOS parameters.  This ioctl is issued
 * by the daemon at NetBIOS startup time.  It is only accepted on the daemon's
 * dev (minor 0).  The argument to the ioctl is a struct nb_init, defined
 * below.
 *
 * Following the structure are a character string ni_scope_len long
 * Following that is an array of ni_naddr nb_ifinfo structures 
 *
 */


struct nb_init {
	int ni_dfltncb;			/* default max active commands */
	int ni_dfltssn;			/* default max sessions */
	int ni_maxname;			/* max names registered per user */
	int ni_maxncb;			/* max active NCBs per user */
	int ni_maxssn;			/* max active sessions per user */
	int ni_sorder;			/* search order - see below for vals */
	/*
	 * ni_scope_len gives the length in bytes of the scope name string,
	 * which follows this structure in the ioctl data.
	 */
	int ni_scope_len;		/* length of scope name */
	/* ni_scope_len of scope */

#ifndef	IPADDR
#define	IPADDR	unsigned long
#endif	/* IPADDR */
	IPADDR 	ni_wins1;	/* IP address of Primary WINS
					   server			*/
	IPADDR 	ni_wins2;	/* IP address of Secondary WINS
					   server			*/

};



#define NIOC		('N' << 8)
#define NB_IOC_INIT	(NIOC | 1)	

#define NB_SO_PASS1_RESOLV 	0x01
#define NB_SO_PASS1_BC 		0x02
#define NB_SO_PASS1_WINS	0x04
#define NB_SO_PASS2_RESOLV 	0x10
#define NB_SO_PASS2_BC 		0x20
#define NB_SO_PASS2_WINS 	0x40
#define NB_SO_PASS3_RESOLV 	0x100
#define NB_SO_PASS3_BC 		0x200
#define NB_SO_PASS3_WINS 	0x400

#define	NB_SO_PASS1	(NB_SO_PASS1_RESOLV | NB_SO_PASS1_BC | NB_SO_PASS1_WINS)
#define	NB_SO_PASS2	(NB_SO_PASS2_RESOLV | NB_SO_PASS2_BC | NB_SO_PASS2_WINS)
#define	NB_SO_PASS3	(NB_SO_PASS3_RESOLV | NB_SO_PASS3_BC | NB_SO_PASS3_WINS)
#define	NB_SO_SHIFT	4

/*
 * NB_IOC_ASSOC associates one dev with the user environment for
 * the dev on which the ioctl is issued.  The user environment of the
 * second device is discarded.  This ioctl must be issued before any
 * commands have been submitted on the dev to be associated.  The two
 * devices must also have been opened by the same uid.  The argument
 * to the ioctl is the device number (st_rdev field of the stats struct)
 * of the device to associate (type dev_t).
 */
#define NB_IOC_ASSOC	(NIOC | 2)

/*
 * NB_IOC_NOLIMIT effectively removes the limits on number of names, sessions,
 * and pending NCBs that a user may have (by setting those limits to the
 * maximum possible values).  This ioctl is restricted to superuser.
 * This ioctl has no arguments.
 */
#define NB_IOC_NOLIMIT	(NIOC | 3)

/*
 * NB_IOC_INTERNAL sets the device to be used for internal (kernel) NCB
 * submission.  NCBs submitted through do_ncb appear to have come from
 * this device (i.e., they are enqueued on this device's write queue).
 * This ioctl is restricted to superuser.  This ioctl has no arguments.
 */
#define NB_IOC_INTERNAL	(NIOC | 4)

/*
 * NB_IOC_TPI - like NB_IOC_INTERNAL, but sets dev to be the placeholder
 * for the TPI environment.
 */
#define NB_IOC_TPI	(NIOC | 5)

/*
 * NB_IOC_VPIX - sets the NB_USR_VPIX flag for the user.  This causes
 * the first reply message to any command to be sent as an M_PCPROTO.
 */
#define NB_IOC_VPIX	(NIOC | 6)

#define NB_IOC_AINIT	(NIOC | 7)

/* data structure for containing interface information */

struct nb_ifinfo {
        unsigned long i_addr;
        unsigned long i_baddr;
        short i_mtu;
	struct nb_ifinfo *i_next;
};

/* structure for use when passing address info down to the kernel */
 
struct nb_ainit {
	int na_naddr;			/* number of address pairs */
	struct nb_ifinfo na_if[1];	/* start of list passed down */
};

/*
 * Adapter Status ioctl definitions
 */

#define NBIOCTL_ASTAT_IP	(NIOC | 0x32)	/* was ifdef'd ASTAT_IP */

#define NBIOCTL_ASTAT	(NIOC | 0x33)
#define NBIOCTL_SSTAT	(NIOC | 0x34)

/*
 * NBIOCTL_NAMESERVER associates a WINS netbios name server with that device.
 * This ioctl is restricted to the superuser. There is no associated data.
 */

#define NBIOCTL_NBNS	(NIOC | 0x40)

/*
 * NBIOCTL_CACHE ioctls used to manage the NetBIOS name cache.
 */

#define NBIOCTL_CACHE_INFO	(NIOC | 0x50)
#define NBIOCTL_CACHE_ADDHOST	(NIOC | 0x51)
#define NBIOCTL_CACHE_DELNAME	(NIOC | 0x52)
#define NBIOCTL_CACHE_GETADDR	(NIOC | 0x53)
#define NBIOCTL_CACHE_GETALL	(NIOC | 0x54)
#define NBIOCTL_CACHE_DELALL	(NIOC | 0x55)

/*
 * Structure of host information from LMHOSTS
 */

struct nbioc_host {
	char	name[NB_NAMESIZE];
	long	ipaddr;
};

/*
 * NBIOCTL_CACHE ioctls used to manage the NetBIOS group cache.
 */

#define NBIOCTL_CACHE_ADDGRP	(NIOC | 0x56)
#define NBIOCTL_CACHE_DELGRP	(NIOC | 0x57)

/*
 * NBIOCTL_CACHE ioctls used to read the Host and Group name
 * name information from the caches
 */
#define NBIOCTL_CACHE_GETHOST	(NIOC | 0x58)
#define NBIOCTL_CACHE_GETGRP	(NIOC | 0x59)

/*
 * Structure of group information from LMHOSTS
 */

struct nbioc_group {
	char	name[NB_NAMESIZE];
	char	member[MAXMEMBERS][NB_NAMESIZE];
};

/* 
 * Structure for DNS lookup messages passed to/from the daemon 
 */

#define NB_IOC_DNS		(NIOC | 0x70)

struct nb_dns {
	int 		d_cmd;
        char            d_name[NB_NAMESIZE];
        unsigned int    d_id;
        ulong		d_addr;
	unsigned int 	d_len;
};

/*
 * command types for d_cmd
 * 
 * NB_CMD_DNS == resolve this name
 * 0 == array of ints for unlink follows, do not generate more endpoints
 * >0 == array of ints for unlink follows, generate more endpoints
 */
#define NB_CMD_DNS	-1

#endif /* __nb_ioctl_h */
